from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # code (SystemRestfulInteraction)
    from spark_auto_mapper_fhir.value_sets.system_restful_interaction import (
        SystemRestfulInteractionCode,
    )

    # documentation (markdown)
    from spark_auto_mapper_fhir.fhir_types.markdown import FhirMarkdown


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class CapabilityStatementInteraction1(FhirBackboneElementBase):
    """
    CapabilityStatement.Interaction1
        A Capability Statement documents a set of capabilities (behaviors) of a FHIR Server for a particular version of FHIR that may be used as a statement of actual server functionality or a statement of required or desired server implementation.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        code: SystemRestfulInteractionCode,
        documentation: Optional[FhirMarkdown] = None,
    ) -> None:
        """
            A Capability Statement documents a set of capabilities (behaviors) of a FHIR
        Server for a particular version of FHIR that may be used as a statement of
        actual server functionality or a statement of required or desired server
        implementation.

            :param id_: id of resource
            :param extension: extensions
            :param code: A coded identifier of the operation, supported by the system.
            :param documentation: Guidance specific to the implementation of this operation, such as limitations
        on the kind of transactions allowed, or information about system wide search
        is implemented.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            code=code,
            documentation=documentation,
        )
