from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

from spark_auto_mapper_fhir.fhir_types.boolean import FhirBoolean
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.resources.resource import Resource

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # sequence (positiveInt)
    from spark_auto_mapper_fhir.fhir_types.positive_int import FhirPositiveInt

    # information (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for information
    # appliesToAll (boolean)


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class CoverageEligibilityRequestSupportingInfo(FhirBackboneElementBase):
    """
    CoverageEligibilityRequest.SupportingInfo
        The CoverageEligibilityRequest provides patient and insurance coverage information to an insurer for them to respond, in the form of an CoverageEligibilityResponse, with information regarding whether the stated coverage is valid and in-force and optionally to provide the insurance details of the policy.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        sequence: FhirPositiveInt,
        information: Reference[Union[Resource]],
        appliesToAll: Optional[FhirBoolean] = None,
    ) -> None:
        """
            The CoverageEligibilityRequest provides patient and insurance coverage
        information to an insurer for them to respond, in the form of an
        CoverageEligibilityResponse, with information regarding whether the stated
        coverage is valid and in-force and optionally to provide the insurance details
        of the policy.

            :param id_: id of resource
            :param extension: extensions
            :param sequence: A number to uniquely identify supporting information entries.
            :param information: Additional data or information such as resources, documents, images etc.
        including references to the data or the actual inclusion of the data.
            :param appliesToAll: The supporting materials are applicable for all detail items, product/servce
        categories and specific billing codes.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            sequence=sequence,
            information=information,
            appliesToAll=appliesToAll,
        )
