from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

from spark_auto_mapper_fhir.fhir_types.boolean import FhirBoolean
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.resources.resource import Resource

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # reference (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for reference
    # exampleBoolean (boolean)
    # exampleCanonical (canonical)
    from spark_auto_mapper_fhir.fhir_types.canonical import FhirCanonical

    # relativePath (url)
    from spark_auto_mapper_fhir.fhir_types.url import FhirUrl


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ImplementationGuideResource1(FhirBackboneElementBase):
    """
    ImplementationGuide.Resource1
        A set of rules of how a particular interoperability or standards problem is solved - typically through the use of FHIR resources. This resource is used to gather all the parts of an implementation guide into a logical whole and to publish a computable definition of all the parts.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        reference: Reference[Union[Resource]],
        exampleBoolean: Optional[FhirBoolean] = None,
        exampleCanonical: Optional[FhirCanonical] = None,
        relativePath: Optional[FhirUrl] = None,
    ) -> None:
        """
            A set of rules of how a particular interoperability or standards problem is
        solved - typically through the use of FHIR resources. This resource is used to
        gather all the parts of an implementation guide into a logical whole and to
        publish a computable definition of all the parts.

            :param id_: id of resource
            :param extension: extensions
            :param reference: Where this resource is found.
            :param exampleBoolean: None
            :param exampleCanonical: None
            :param relativePath: The relative path for primary page for this resource within the IG.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            reference=reference,
            exampleBoolean=exampleBoolean,
            exampleCanonical=exampleCanonical,
            relativePath=relativePath,
        )
