from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # name (string)
    # software (string)
    # version (string)
    # contact (ContactPoint)
    from spark_auto_mapper_fhir.complex_types.contact_point import ContactPoint

    # endpoint (url)
    from spark_auto_mapper_fhir.fhir_types.url import FhirUrl


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class MessageHeaderSource(FhirBackboneElementBase):
    """
    MessageHeader.Source
        The header for a message exchange that is either requesting or responding to an action.  The reference(s) that are the subject of the action as well as other information related to the action are typically transmitted in a bundle in which the MessageHeader resource instance is the first resource in the bundle.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        name: Optional[FhirString] = None,
        software: Optional[FhirString] = None,
        version: Optional[FhirString] = None,
        contact: Optional[ContactPoint] = None,
        endpoint: FhirUrl,
    ) -> None:
        """
            The header for a message exchange that is either requesting or responding to
        an action.  The reference(s) that are the subject of the action as well as
        other information related to the action are typically transmitted in a bundle
        in which the MessageHeader resource instance is the first resource in the
        bundle.

            :param id_: id of resource
            :param extension: extensions
            :param name: Human-readable name for the source system.
            :param software: May include configuration or other information useful in debugging.
            :param version: Can convey versions of multiple systems in situations where a message passes
        through multiple hands.
            :param contact: An e-mail, phone, website or other contact point to use to resolve issues with
        message communications.
            :param endpoint: Identifies the routing target to send acknowledgements to.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            name=name,
            software=software,
            version=version,
            contact=contact,
            endpoint=endpoint,
        )
